==> huaweicloudsdkaom-3.1.117-py2.py3-none-any.whl: huaweicloudsdkaom/v2/model/delete_metric_or_event_alarm_rule_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteMetricOrEventAlarmRuleRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'body': 'DeleteAlarmRuleV4RequestBody'
    }

    attribute_map = {
        'body': 'body'
    }

    def __init__(self, body=None):
        """DeleteMetricOrEventAlarmRuleRequest

        The model defined in huaweicloud sdk

        :param body: Body of the DeleteMetricOrEventAlarmRuleRequest
        :type body: :class:`huaweicloudsdkaom.v2.DeleteAlarmRuleV4RequestBody`
        """
        
        

        self._body = None
        self.discriminator = None

        if body is not None:
            self.body = body

    @property
    def body(self):
        """Gets the body of this DeleteMetricOrEventAlarmRuleRequest.

        :return: The body of this DeleteMetricOrEventAlarmRuleRequest.
        :rtype: :class:`huaweicloudsdkaom.v2.DeleteAlarmRuleV4RequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this DeleteMetricOrEventAlarmRuleRequest.

        :param body: The body of this DeleteMetricOrEventAlarmRuleRequest.
        :type body: :class:`huaweicloudsdkaom.v2.DeleteAlarmRuleV4RequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteMetricOrEventAlarmRuleRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkaom-3.1.153-py2.py3-none-any.whl: huaweicloudsdkaom/v2/model/delete_metric_or_event_alarm_rule_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeleteMetricOrEventAlarmRuleRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'body': 'DeleteAlarmRuleV4RequestBody'
    }

    attribute_map = {
        'body': 'body'
    }

    def __init__(self, body=None):
        r"""DeleteMetricOrEventAlarmRuleRequest

        The model defined in huaweicloud sdk

        :param body: Body of the DeleteMetricOrEventAlarmRuleRequest
        :type body: :class:`huaweicloudsdkaom.v2.DeleteAlarmRuleV4RequestBody`
        """
        
        

        self._body = None
        self.discriminator = None

        if body is not None:
            self.body = body

    @property
    def body(self):
        r"""Gets the body of this DeleteMetricOrEventAlarmRuleRequest.

        :return: The body of this DeleteMetricOrEventAlarmRuleRequest.
        :rtype: :class:`huaweicloudsdkaom.v2.DeleteAlarmRuleV4RequestBody`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this DeleteMetricOrEventAlarmRuleRequest.

        :param body: The body of this DeleteMetricOrEventAlarmRuleRequest.
        :type body: :class:`huaweicloudsdkaom.v2.DeleteAlarmRuleV4RequestBody`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteMetricOrEventAlarmRuleRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
